package com.example.android.ar.simple;

import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.List;

import com.example.android.ar.simple.R;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.location.Location;
import android.os.AsyncTask;

/**
 * 端末の東西南北500m地点にマーカーを設置するためのクラスです。
 * 
 */
public class DirectionTask extends AsyncTask<Location, Void, List<ProximityObject>> {

    private static final int DISTANCE_METRE = 500; // (m)

    private LocationsView cameraOverlay;
    private Bitmap bitmap;
    
    public DirectionTask(Context context, LocationsView cameraOverlay) {
        this.cameraOverlay = cameraOverlay;
        bitmap = BitmapFactory.decodeResource(context.getResources(), R.drawable.android);
    }

    @Override
    protected List<ProximityObject> doInBackground(Location... params) {
        Location location = params[0];

        List<ProximityObject> results = new ArrayList<ProximityObject>(4);
        double[] result = new double[2];

        locate(location, (int) (DISTANCE_METRE * Math.sin(Math.toRadians(90))), (int) (DISTANCE_METRE * Math.cos(Math.toRadians(90))), result);
        ProximityObject north = createProximity(result, "北");
        results.add(north);

        locate(location, (int) (DISTANCE_METRE * Math.sin(Math.toRadians(45))), (int) (DISTANCE_METRE * Math.cos(Math.toRadians(45))), result);
        ProximityObject northEast = createProximity(result, "北東");
        results.add(northEast);

        locate(location, (int) (DISTANCE_METRE * Math.sin(Math.toRadians(0))), (int) (DISTANCE_METRE * Math.cos(Math.toRadians(0))), result);
        ProximityObject east = createProximity(result, "東");
        results.add(east);

        locate(location, (int) (DISTANCE_METRE * Math.sin(Math.toRadians(315))), (int) (DISTANCE_METRE * Math.cos(Math.toRadians(315))), result);
        ProximityObject southEast = createProximity(result, "南東");
        results.add(southEast);

        locate(location, (int) (DISTANCE_METRE * Math.sin(Math.toRadians(270))), (int) (DISTANCE_METRE * Math.cos(Math.toRadians(270))), result);
        ProximityObject south = createProximity(result, "南");
        results.add(south);

        locate(location, (int) (DISTANCE_METRE * Math.sin(Math.toRadians(225))), (int) (DISTANCE_METRE * Math.cos(Math.toRadians(225))), result);
        ProximityObject southWest = createProximity(result, "南西");
        results.add(southWest);

        locate(location, (int) (DISTANCE_METRE * Math.sin(Math.toRadians(180))), (int) (DISTANCE_METRE * Math.cos(Math.toRadians(180))), result);
        ProximityObject west = createProximity(result, "西");
        results.add(west);

        locate(location, (int) (DISTANCE_METRE * Math.sin(Math.toRadians(135))), (int) (DISTANCE_METRE * Math.cos(Math.toRadians(135))), result);
        ProximityObject northWest = createProximity(result, "北西");
        results.add(northWest);

        return results;
    }

    // 地球の半径(m)
    private static final double EARTH_RADIUS = 6378150;
    // 地球の最大円周(m)
    private static final double EARTH_CIRCUMFERENCE = 2 * Math.PI * EARTH_RADIUS;

    // １°を秒数換算した値
    private static final double DEGREE_IN_MINUTE = 60 * 60;

    // 円周(秒)
    private static final double CIRCUMFERENCE_MINUTES = 360 * DEGREE_IN_MINUTE;

    public static void locate(Location location, int latDistance, int lngDistance, double[] result) {

        // 1メートルあたりの緯度(秒)
        double latitudePerMetreInMinutes = CIRCUMFERENCE_MINUTES / EARTH_CIRCUMFERENCE;

        // 指定の緯度での円周
        double circumferenceAtOfLatitude = EARTH_CIRCUMFERENCE * Math.cos(Math.toRadians(location.getLatitude()));

        // 1メートルあたりの経度(秒)
        double longitudePerMetreInMinutes = CIRCUMFERENCE_MINUTES / circumferenceAtOfLatitude;

        double lat = location.getLatitude() + latDistance * latitudePerMetreInMinutes / DEGREE_IN_MINUTE;
        double lng = location.getLongitude() + lngDistance * longitudePerMetreInMinutes / DEGREE_IN_MINUTE;

        result[0] = lat;
        result[1] = lng;
    }

    private ProximityObject createProximity(double[] location, String name) {
        ProximityObject p = new ProximityObject();
        p.name = name;
        p.latitude = location[0];
        p.longitude = location[1];
        p.url = "http://ja.m.wikipedia.org/wiki/" + URLEncoder.encode(name);
        p.drawer = bitmap;
        return p;
    }

    @Override
    protected void onPostExecute(List<ProximityObject> result) {
        if (result == null)
            return;
        // 位置情報オブジェクトの更新をオーバーレイに通知します。
        cameraOverlay.updateProximityList(result);
    }
}
