package com.example.android.ar.simple;

import java.util.ArrayList;
import java.util.List;

import android.content.Context;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.AsyncTask;

/**
 * 端末の記録された位置情報を検索するためのクラスです。
 * 
 * 
 */
public class FetchDatabaseTask extends AsyncTask<Void, Void, List<ProximityObject>> {

    private Context context;
    private LocationsView cameraOverlay;
    private Bitmap bitmap;
    
    public FetchDatabaseTask(Context context, LocationsView cameraOverlay) {
        this.context = context;
        this.cameraOverlay = cameraOverlay;
        bitmap = BitmapFactory.decodeResource(context.getResources(), R.drawable.green_dot);
    }

    @Override
    protected List<ProximityObject> doInBackground(Void... params) {

        LocationDatabase database = new LocationDatabase(context);
        Cursor locations = database.fetchAll();
        List<ProximityObject> results = new ArrayList<ProximityObject>();

        try {
            // カーソルから緯度、経度、時刻を取得するためのインデックスをキャッシュします。
            int latitudeIndex = locations.getColumnIndex("latitude");
            int longitudeIndex = locations.getColumnIndex("longitude");
            int nameIndex = locations.getColumnIndex("name");
            // int timeIndex = locations.getColumnIndex("time");

            while (locations.moveToNext()) {
                ProximityObject p = null;
                p = new ProximityObject();
                p.name = locations.getString(nameIndex);
                p.latitude = locations.getDouble(latitudeIndex);
                p.longitude = locations.getDouble(longitudeIndex);
                p.url = "geo:" + p.latitude + "," + p.longitude + "?z=16";
                p.drawer = bitmap;
                results.add(p);

            }
        } finally {
            locations.close();
            database.close();
        }

        return results;
    }

    @Override
    protected void onPostExecute(List<ProximityObject> result) {
        if (result == null)
            return;
        // 位置情報オブジェクトの更新をオーバーレイに通知します。
        cameraOverlay.updateProximityList(result);
    }
}
