package com.example.android.ar.simple;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.location.Location;

/**
 * 位置情報を扱うデータアクセスオブジェクト(DAO)。
 *
 */
public class LocationDatabase extends SQLiteOpenHelper {

    
    /** 検索結果に含める、locationテーブルのカラム */
    private static final String[] COLUMNS = { "_id", "latitude", "longitude", "name", "time"};

    public LocationDatabase(Context context) {
        super(context, "data", null, 1);
    }

    @Override
    public void onCreate(SQLiteDatabase db) {
        // 位置情報を保存するためのテーブル "location" を作成します。
        // テーブルは、IDと緯度(latitude)、経度(longitude)、名前(name)、記録時間(time)を持ちます。
        db.execSQL("create table location ("
                + "_id integer primary key autoincrement," 
                + "latitude text not null, " 
                + "longitude text not null, " 
                + "name text, "
                + "time text not null "                 
                + ")");
    }

    @Override
    public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
        db.execSQL("drop table if exists location");
        onCreate(db);
    }

    /**
     * 位置情報に名前をつけて保存します。
     * @param location
     * @param name
     * @return
     */
    public long insert(Location location, String name) {
        synchronized (this) {
            ContentValues values = new ContentValues();
            values.put("latitude", Double.toString(location.getLatitude()));
            values.put("longitude", Double.toString(location.getLongitude()));
            values.put("name", name);
            values.put("time", Long.toString(location.getTime()));

            SQLiteDatabase db = getWritableDatabase();
            try {
                return db.insert("location", null, values);
            } finally {
                db.close();
            }
        }
    }

    /**
     * 保存された位置情報を検索します。
     * @return
     */
    public Cursor fetchAll() {
        synchronized (this) {
            SQLiteDatabase db = getReadableDatabase();
            return db.query("location", COLUMNS, null, null, null, null, "time");
        }
    }

    /**
     * 保存された位置情報を削除します。
     * @return
     */
    public int deleteAll() {
        synchronized (this) {
            SQLiteDatabase db = getWritableDatabase();
            onUpgrade(db, 0, 0);
            try {
                return db.delete("location", null, null);
            } finally {
                db.close();
            }
        }
    }
}
