package com.example.android.ar.simple;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.apache.http.HttpResponse;
import org.apache.http.NameValuePair;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.utils.URLEncodedUtils;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import com.example.android.ar.simple.R;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.location.Location;
import android.os.AsyncTask;
import android.util.Log;

/**
 * 端末の近くに存在する位置情報を検索するためのクラスです。
 * 
 * 本記事ではgoogle ajax apiを使って、近隣のレストランを検索します。
 * 
 */
public class ProximitySearchTask extends AsyncTask<Location, Void, List<ProximityObject>> {

    private static final String TAG = "ARExample";

    /** 検索キーワード。駅、コンビニなど変更してみてください。 */
    private static final String QUERY = "レストラン";

    private LocationsView cameraOverlay;
    private Bitmap bitmap;
    
    public ProximitySearchTask(Context context, LocationsView cameraOverlay) {
        this.cameraOverlay = cameraOverlay;
        bitmap = BitmapFactory.decodeResource(context.getResources(), R.drawable.red_dot);
    }

    @Override
    protected List<ProximityObject> doInBackground(Location... params) {
        Location location = params[0];
        double latitude = location.getLatitude();
        double longitude = location.getLongitude();

        List<NameValuePair> formparams = new ArrayList<NameValuePair>();
        formparams.add(new BasicNameValuePair("v", "3.0"));

        // 検索に使う言語を日本語に設定します。
        formparams.add(new BasicNameValuePair("hl", "jp"));
        // 検索キーワードを設定します。
        formparams.add(new BasicNameValuePair("q", QUERY));
        // 検索結果の件数を設定します。最大8
        //formparams.add(new BasicNameValuePair("rsz", "8"));
        // 緯度と経度を設定します。キーワードに合致し、ここで指定した緯度・経度の付近に存在するものが検索結果になります。
        formparams.add(new BasicNameValuePair("sll", latitude + "," + longitude));
        String query = URLEncodedUtils.format(formparams, "utf-8");

        HttpGet req = new HttpGet("http://ajax.googleapis.com/ajax/services/search/local?" + query);
        Log.d(TAG, req.getURI().toString());

        HttpClient client = new DefaultHttpClient();

        String content;
        try {
            HttpResponse resp = client.execute(req);
            content = EntityUtils.toString(resp.getEntity());
        } catch (ClientProtocolException e) {
            req.abort();
            return null;
        } catch (IOException e) {
            req.abort();
            return null;
        }

        //検索結果からProximityObjectを生成します。
        
        List<ProximityObject> results = null;

        try {
            JSONObject json = new JSONObject(content);
            JSONObject jResponseData = json.getJSONObject("responseData");
            JSONArray jsonResult = jResponseData.getJSONArray("results");
            int count = jsonResult.length();
            results = new ArrayList<ProximityObject>(count);
            for (int i = 0; i < count; ++i) {
                JSONObject result = jsonResult.getJSONObject(i);
                ProximityObject p = null;
                p = new ProximityObject();
                p.name = result.getString("titleNoFormatting");
                p.latitude = result.getDouble("lat");
                p.longitude = result.getDouble("lng");
                p.drawer = bitmap;
                p.url = result.getString("url");
                Log.d(TAG, p.name);
                results.add(p);
            }
        } catch (JSONException e) {
            return null;
        } finally {
            req.abort();
        }

        return results;
    }

    @Override
    protected void onPostExecute(List<ProximityObject> result) {
        if (result == null)
            return;
        //位置情報オブジェクトの更新をオーバーレイに通知します。
        cameraOverlay.updateProximityList(result);
    }
}
